@@ -6,29 +6,30 @@
 
 import io
 import sys
+
 from trezorlib import misc, ui
 from trezorlib.client import TrezorClient
 from trezorlib.transport import get_transport
 
 
-def main():
+def main() -> None:
     try:
         client = TrezorClient(get_transport(), ui=ui.ClickUI())
     except Exception as e:
         print(e)
         return
 
-    arg1 = sys.argv[1]                     # output file
-    arg2 = int(sys.argv[2], 10)            # total number of how many bytes of entropy to read
+    arg1 = sys.argv[1]  # output file
+    arg2 = int(sys.argv[2], 10)  # total number of how many bytes of entropy to read
     step = 1024 if arg2 >= 1024 else arg2  # trezor will only return 1KB at a time
 
-    with io.open(arg1, 'wb') as f:
-        for i in range(0, arg2, step):
+    with io.open(arg1, "wb") as f:
+        for _ in range(0, arg2, step):
             entropy = misc.get_entropy(client, step)
             f.write(entropy)
 
     client.close()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
